import { srsUrl } from "@config";

const routeDef: RouteDef = {
	method: "GET",
	accepts: "*/*",
	returns: "application/json",
};

async function handler(): Promise<Response> {
	try {
		const response = await fetch(`${srsUrl}/api/v1/streams`);

		if (!response.ok) {
			return Response.json(
				{
					success: false,
					code: response.status,
					error: `SRS API error: ${response.statusText}`,
				},
				{ status: response.status },
			);
		}

		const data = await response.json();

		return Response.json({
			success: true,
			data,
		});
	} catch {
		return Response.json(
			{
				success: false,
				code: 500,
				error: "Failed to fetch streams from SRS server",
			},
			{ status: 500 },
		);
	}
}

export { handler, routeDef };
