import { resolve } from "node:path";

const routeDef: RouteDef = {
	method: "GET",
	accepts: "*/*",
	returns: "text/html",
};

async function handler(request: ExtendedRequest): Promise<Response> {
	const { id } = request.params;

	if (!id) {
		return new Response("Chat ID is required", { status: 400 });
	}

	const filePath = resolve("public", "chat.html");
	const bunFile = Bun.file(filePath);

	if (!(await bunFile.exists())) {
		return new Response("Chat page not found", { status: 404 });
	}

	const html = new HTMLRewriter()
		.on("head", {
			element(head) {
				head.append(`<meta name="chat-id" content="${id}">`, {
					html: true,
				});
			},
		})
		.transform(await bunFile.text());

	return new Response(html, {
		headers: {
			"Content-Type": "text/html",
		},
	});
}

export { handler, routeDef };
