import { resolve } from "node:path";
import { srsUrl } from "@config";

const routeDef: RouteDef = {
	method: "GET",
	accepts: "*/*",
	returns: "text/html",
};

async function handler(request: ExtendedRequest): Promise<Response> {
	const { id } = request.params;

	if (!id) {
		return new Response("Stream ID is required", { status: 400 });
	}

	const filePath = resolve("public", "watch.html");
	const bunFile = Bun.file(filePath);

	const html = new HTMLRewriter()
		.on("head", {
			element(head) {
				head.append(`<meta name="srs-url" content="${srsUrl}">`, {
					html: true,
				});
				head.append(`<meta name="stream-id" content="${id}">`, {
					html: true,
				});
			},
		})
		.transform(await bunFile.text());

	return new Response(html, {
		headers: {
			"Content-Type": "text/html",
		},
	});
}

export { handler, routeDef };
